@@ -10,12 +10,12 @@
 */
 
 /* .Call calls */
-extern SEXP RLumModel_set_ODE_Rcpp(SEXP, SEXP, SEXP);
-extern SEXP RLumModel_set_ODE_Rcpp_LM_OSL(SEXP, SEXP, SEXP);
+extern SEXP _RLumModel_set_ODE_Rcpp(SEXP, SEXP, SEXP);
+extern SEXP _RLumModel_set_ODE_Rcpp_LM_OSL(SEXP, SEXP, SEXP);
 
 static const R_CallMethodDef CallEntries[] = {
-    {"RLumModel_set_ODE_Rcpp",        (DL_FUNC) &RLumModel_set_ODE_Rcpp,        3},
-    {"RLumModel_set_ODE_Rcpp_LM_OSL", (DL_FUNC) &RLumModel_set_ODE_Rcpp_LM_OSL, 3},
+    {"_RLumModel_set_ODE_Rcpp",        (DL_FUNC) &_RLumModel_set_ODE_Rcpp,        3},
+    {"_RLumModel_set_ODE_Rcpp_LM_OSL", (DL_FUNC) &_RLumModel_set_ODE_Rcpp_LM_OSL, 3},
     {NULL, NULL, 0}
 };
 
