@@ -21,6 +21,22 @@ test_that("check class and output", {
   
 })
 
+test_that("check simulate_sample_history = TRUE", {
+  
+  output <- model_LuminescenceSignals(
+    model = "Bailey2001", 
+    sequence = list(
+      RF = c(20, 1, 1)),
+    plot = FALSE, 
+    simulate_sample_history = TRUE,
+    show_structure = TRUE,
+    verbose = FALSE)
+  
+  expect_equal(length(output), 12)
+  expect_equal(is(output), c("RLum.Analysis", "RLum"))
+
+  })
+
 
 test_that("check SAR sequence", {
   
@@ -201,7 +217,7 @@ test_that("test controlled crash conditions", {
       model = "Bailey2000",
       sequence = list(
         OSL = c(20,1,100))),
-    regexp = "[model_LuminescenceSignals()] Model not supported. Supported models are: Bailey2001, Bailey2004, Pagonis2008, Pagonis2007, Bailey2002, Friedrich2017, customized",
+    regexp = "[model_LuminescenceSignals()] Model not supported. Supported models are: Bailey2001, Bailey2004, Pagonis2008, Pagonis2007, Bailey2002, Friedrich2017, Friedrich2018, customized",
     fixed = TRUE)
   
   expect_error(
@@ -226,4 +242,11 @@ test_that("test controlled crash conditions", {
     regexp = "[model_LuminescenceSignals()] Argument 'model' set to 'customized', but no own parameters are given!",
     fixed = TRUE)
   
+  expect_error(
+    model_LuminescenceSignals(
+      model = "customized",
+      sequence = list(TLL = c(20,100,5))),
+    regexp = "[model_LuminescenceSignals()] Unknow sequence arguments: Allowed arguments are: IRR, PH, CH, TL, OSL, PAUSE, LM_OSL, RL, RF, ILL, RF_heating",
+    fixed = TRUE)
+  
 })
\ No newline at end of file
